==> dbmodel-0.2.1.tar.gz: dbmodel-0.2.1/dbmodel/model.py <==
from collections import namedtuple


class DbModel:

    ID = "id"
    NAME = "name"
    EMAIL = "email"
    PASSWORD_HASH = "password_hash"
    HOURS = "hour"
    MINUTES = "minutes"
    GENDER = "gender"

    BRAINQUIST_TEXT = "brainquist_text"
    BRAINQUIST_TEXT_NO_SSML = "brainquist_text_no_ssml"
    USER_TEXT = "user_text"
    NEXT_MODE = "next_mode"
    TIMESTAMP_UTC = "timestamp_utc"
    ROUTINES_LIST = "routines_list"

    CARE_GIVERS = "care_givers"
    PATIENTS_LOGS = "patients_logs"

    PATIENTS = "patients"
    ROUTINES = "routines"
    ROUTINES_LOGS = "routines_logs"
    DATA_LOG = "data_log"

    CARE_GIVER_ID = "care_giver_id"
    END_CONVERSATION = "end_conversation"
    END_TASK = "end_task"
    TURN = "turn"
    ROUTINE_ID = "routine_id"
    PATIENT_ID = "patients_id"
    SESSION_ID = "session_id"
    INITIAL_PHASE = "initial_phase"
    FINISHED_ROUTINES = "finished_routines"
    SUCCESSFULLY_FINISHED = "successfully_finished"
    SUCCESSFULLY_FINISHED_ROUTINES_LIST = "successfully_finished_routines_list"
    ROUTINE_DATA = "routine_data"
    SILENT_THRESHOLD = "silent_threshold"
    PAUSE_LIMIT = "pause_limit"
    CONFIDENCE_SCORE = "confidence_score"
    EXPECTED_PHRASES = "expected_phrases"

    # The response provided to client when he asks about possible work to do
    # Because of docker-version compatibility
    NO_TASK = "no_task"

    # The ``phrase_time_limit`` parameter is the maximum number of seconds that this will allow a phrase to continue
    # before stopping and returning the part of the phrase processed before the time limit was reached.
    #  The resulting audio will be the phrase cut off at the time limit.
    PHRASE_TIME_LIMIT = "phrase_time_limit"


Task = namedtuple("Task", "concat_name underscore_name normal_name")


class Tasks:
    repeat_words = Task("repeatwords", "repeat_words", "Repeat Words")
    basic_math = Task("basicmath", "basic_math", "Basic Math")
    jobs_start_at = Task("jobsstartsat", "jobs_start_at", "Jobs Started At")

    @staticmethod
    def get_concat_name(item: Task):
        return item.concat_name

    @staticmethod
    def get_underscore_name(item: Task):
        return item.underscore_name

    @staticmethod
    def get_normal_name(item: Task):
        return item.normal_name

==> dbmodel-0.3.1.tar.gz: dbmodel-0.3.1/dbmodel/model.py <==
from collections import namedtuple


class DbModel:

    ID = "id"
    NAME = "name"
    EMAIL = "email"
    PASSWORD_HASH = "password_hash"
    HOURS = "hour"
    MINUTES = "minutes"
    GENDER = "gender"

    BRAINQUIST_TEXT = "brainquist_text"
    BRAINQUIST_TEXT_NO_SSML = "brainquist_text_no_ssml"
    USER_TEXT = "user_text"
    NEXT_MODE = "next_mode"
    TIMESTAMP_UTC = "timestamp_utc"
    ROUTINES_LIST = "routines_list"

    CARE_GIVERS = "care_givers"
    PATIENTS_LOGS = "patients_logs"

    PATIENTS = "patients"
    ROUTINES = "routines"
    ROUTINES_LOGS = "routines_logs"
    DATA_LOG = "data_log"

    CARE_GIVER_ID = "care_giver_id"
    END_CONVERSATION = "session_ended"
    END_TASK = "dialogue_ended"
    TURN = "turn"
    ROUTINE_ID = "routine_id"
    PATIENT_ID = "patients_id"
    SESSION_ID = "session_id"
    INITIAL_PHASE = "initial_phase"
    FINISHED_ROUTINES = "finished_routines"
    SUCCESSFULLY_FINISHED = "successfully_finished"
    SUCCESSFULLY_FINISHED_ROUTINES_LIST = "successfully_finished_routines_list"
    ROUTINE_DATA = "routine_data"
    SILENT_THRESHOLD = "silent_threshold"
    PAUSE_LIMIT = "pause_limit"
    CONFIDENCE_SCORE = "confidence_score"
    EXPECTED_PHRASES = "expected_phrases"
    SPEAKING_RATE = "speaking_rate"

    # The response provided to client when he asks about possible work to do
    # Because of docker-version compatibility
    NO_TASK = "no_task"

    # The ``phrase_time_limit`` parameter is the maximum number of seconds that this will allow a phrase to continue
    # before stopping and returning the part of the phrase processed before the time limit was reached.
    #  The resulting audio will be the phrase cut off at the time limit.
    PHRASE_TIME_LIMIT = "phrase_time_limit"

    STATUS = "status"

    #Helena
    HELENA_DIALOGUE_ENDED = END_TASK
    HELENA_SESSION_ENDED = END_CONVERSATION
    HELENA_SSML = "ssml"
    HELENA_TEXT = "text"
    HELENA_STATES = "states"
    HELENA_EXPECTED_PHRASES = EXPECTED_PHRASES


Task = namedtuple("Task", "concat_name underscore_name normal_name")


class Tasks:
    repeat_words = Task("repeatwords", "repeat_words", "Repeat Words")
    basic_math = Task("basicmath", "basic_math", "Basic Math")
    jobs_start_at = Task("jobsstartsat", "jobs_start_at", "Jobs Started At")

    @staticmethod
    def get_concat_name(item: Task):
        return item.concat_name

    @staticmethod
    def get_underscore_name(item: Task):
        return item.underscore_name

    @staticmethod
    def get_normal_name(item: Task):
        return item.normal_name
